tdub.math
---------

A module with math utilities

.. currentmodule:: tdub.math

Function Summary
^^^^^^^^^^^^^^^^

.. autosummary::

   chisquared_cdf_c
   chisquared_test
   kolmogorov_prob
   ks_twosample_binned


Reference
^^^^^^^^^

.. autofunction:: chisquared_cdf_c
.. autofunction:: chisquared_test
.. autofunction:: kolmogorov_prob
.. autofunction:: ks_twosample_binned
